# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ProtoRevealedSecret(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'aws': 'V1AWSCredential',
        'kind': 'str',
        'openai': 'V1OpenAICredential'
    }

    attribute_map = {
        'aws': 'aws',
        'kind': 'kind',
        'openai': 'openai'
    }

    def __init__(self, aws=None, kind=None, openai=None, local_vars_configuration=None):  # noqa: E501
        """ProtoRevealedSecret - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._aws = None
        self._kind = None
        self._openai = None
        self.discriminator = None

        if aws is not None:
            self.aws = aws
        if kind is not None:
            self.kind = kind
        if openai is not None:
            self.openai = openai

    @property
    def aws(self):
        """Gets the aws of this ProtoRevealedSecret.  # noqa: E501


        :return: The aws of this ProtoRevealedSecret.  # noqa: E501
        :rtype: V1AWSCredential
        """
        return self._aws

    @aws.setter
    def aws(self, aws):
        """Sets the aws of this ProtoRevealedSecret.


        :param aws: The aws of this ProtoRevealedSecret.  # noqa: E501
        :type aws: V1AWSCredential
        """

        self._aws = aws

    @property
    def kind(self):
        """Gets the kind of this ProtoRevealedSecret.  # noqa: E501


        :return: The kind of this ProtoRevealedSecret.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this ProtoRevealedSecret.


        :param kind: The kind of this ProtoRevealedSecret.  # noqa: E501
        :type kind: str
        """

        self._kind = kind

    @property
    def openai(self):
        """Gets the openai of this ProtoRevealedSecret.  # noqa: E501


        :return: The openai of this ProtoRevealedSecret.  # noqa: E501
        :rtype: V1OpenAICredential
        """
        return self._openai

    @openai.setter
    def openai(self, openai):
        """Sets the openai of this ProtoRevealedSecret.


        :param openai: The openai of this ProtoRevealedSecret.  # noqa: E501
        :type openai: V1OpenAICredential
        """

        self._openai = openai

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProtoRevealedSecret):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProtoRevealedSecret):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class SamlAttributeConsumingService(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'index': 'int',
        'is_default': 'bool',
        'requested_attributes': 'list[SamlRequestedAttribute]',
        'service_descriptions': 'list[SamlLocalizedName]',
        'service_names': 'list[SamlLocalizedName]'
    }

    attribute_map = {
        'index': 'Index',
        'is_default': 'IsDefault',
        'requested_attributes': 'RequestedAttributes',
        'service_descriptions': 'ServiceDescriptions',
        'service_names': 'ServiceNames'
    }

    def __init__(self, index=None, is_default=None, requested_attributes=None, service_descriptions=None, service_names=None, local_vars_configuration=None):  # noqa: E501
        """SamlAttributeConsumingService - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._index = None
        self._is_default = None
        self._requested_attributes = None
        self._service_descriptions = None
        self._service_names = None
        self.discriminator = None

        if index is not None:
            self.index = index
        self.is_default = is_default
        if requested_attributes is not None:
            self.requested_attributes = requested_attributes
        if service_descriptions is not None:
            self.service_descriptions = service_descriptions
        if service_names is not None:
            self.service_names = service_names

    @property
    def index(self):
        """Gets the index of this SamlAttributeConsumingService.  # noqa: E501


        :return: The index of this SamlAttributeConsumingService.  # noqa: E501
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this SamlAttributeConsumingService.


        :param index: The index of this SamlAttributeConsumingService.  # noqa: E501
        :type index: int
        """

        self._index = index

    @property
    def is_default(self):
        """Gets the is_default of this SamlAttributeConsumingService.  # noqa: E501


        :return: The is_default of this SamlAttributeConsumingService.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this SamlAttributeConsumingService.


        :param is_default: The is_default of this SamlAttributeConsumingService.  # noqa: E501
        :type is_default: bool
        """

        self._is_default = is_default

    @property
    def requested_attributes(self):
        """Gets the requested_attributes of this SamlAttributeConsumingService.  # noqa: E501


        :return: The requested_attributes of this SamlAttributeConsumingService.  # noqa: E501
        :rtype: list[SamlRequestedAttribute]
        """
        return self._requested_attributes

    @requested_attributes.setter
    def requested_attributes(self, requested_attributes):
        """Sets the requested_attributes of this SamlAttributeConsumingService.


        :param requested_attributes: The requested_attributes of this SamlAttributeConsumingService.  # noqa: E501
        :type requested_attributes: list[SamlRequestedAttribute]
        """

        self._requested_attributes = requested_attributes

    @property
    def service_descriptions(self):
        """Gets the service_descriptions of this SamlAttributeConsumingService.  # noqa: E501


        :return: The service_descriptions of this SamlAttributeConsumingService.  # noqa: E501
        :rtype: list[SamlLocalizedName]
        """
        return self._service_descriptions

    @service_descriptions.setter
    def service_descriptions(self, service_descriptions):
        """Sets the service_descriptions of this SamlAttributeConsumingService.


        :param service_descriptions: The service_descriptions of this SamlAttributeConsumingService.  # noqa: E501
        :type service_descriptions: list[SamlLocalizedName]
        """

        self._service_descriptions = service_descriptions

    @property
    def service_names(self):
        """Gets the service_names of this SamlAttributeConsumingService.  # noqa: E501


        :return: The service_names of this SamlAttributeConsumingService.  # noqa: E501
        :rtype: list[SamlLocalizedName]
        """
        return self._service_names

    @service_names.setter
    def service_names(self, service_names):
        """Sets the service_names of this SamlAttributeConsumingService.


        :param service_names: The service_names of this SamlAttributeConsumingService.  # noqa: E501
        :type service_names: list[SamlLocalizedName]
        """

        self._service_names = service_names

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SamlAttributeConsumingService):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SamlAttributeConsumingService):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseCmdkSearchResultInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'hub_key': 'str',
        'name': 'str',
        'organization_name': 'str',
        'project_name': 'str',
        'reference_id': 'int',
        'type': 'str',
        'updated_dt': 'datetime'
    }

    attribute_map = {
        'hub_key': 'hub_key',
        'name': 'name',
        'organization_name': 'organization_name',
        'project_name': 'project_name',
        'reference_id': 'reference_id',
        'type': 'type',
        'updated_dt': 'updated_dt'
    }

    def __init__(self, hub_key=None, name=None, organization_name=None, project_name=None, reference_id=None, type=None, updated_dt=None, local_vars_configuration=None):  # noqa: E501
        """ResponseCmdkSearchResultInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._hub_key = None
        self._name = None
        self._organization_name = None
        self._project_name = None
        self._reference_id = None
        self._type = None
        self._updated_dt = None
        self.discriminator = None

        self.hub_key = hub_key
        self.name = name
        self.organization_name = organization_name
        self.project_name = project_name
        self.reference_id = reference_id
        if type is not None:
            self.type = type
        self.updated_dt = updated_dt

    @property
    def hub_key(self):
        """Gets the hub_key of this ResponseCmdkSearchResultInfo.  # noqa: E501


        :return: The hub_key of this ResponseCmdkSearchResultInfo.  # noqa: E501
        :rtype: str
        """
        return self._hub_key

    @hub_key.setter
    def hub_key(self, hub_key):
        """Sets the hub_key of this ResponseCmdkSearchResultInfo.


        :param hub_key: The hub_key of this ResponseCmdkSearchResultInfo.  # noqa: E501
        :type hub_key: str
        """

        self._hub_key = hub_key

    @property
    def name(self):
        """Gets the name of this ResponseCmdkSearchResultInfo.  # noqa: E501


        :return: The name of this ResponseCmdkSearchResultInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ResponseCmdkSearchResultInfo.


        :param name: The name of this ResponseCmdkSearchResultInfo.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def organization_name(self):
        """Gets the organization_name of this ResponseCmdkSearchResultInfo.  # noqa: E501


        :return: The organization_name of this ResponseCmdkSearchResultInfo.  # noqa: E501
        :rtype: str
        """
        return self._organization_name

    @organization_name.setter
    def organization_name(self, organization_name):
        """Sets the organization_name of this ResponseCmdkSearchResultInfo.


        :param organization_name: The organization_name of this ResponseCmdkSearchResultInfo.  # noqa: E501
        :type organization_name: str
        """
        if self.local_vars_configuration.client_side_validation and organization_name is None:  # noqa: E501
            raise ValueError("Invalid value for `organization_name`, must not be `None`")  # noqa: E501

        self._organization_name = organization_name

    @property
    def project_name(self):
        """Gets the project_name of this ResponseCmdkSearchResultInfo.  # noqa: E501


        :return: The project_name of this ResponseCmdkSearchResultInfo.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this ResponseCmdkSearchResultInfo.


        :param project_name: The project_name of this ResponseCmdkSearchResultInfo.  # noqa: E501
        :type project_name: str
        """

        self._project_name = project_name

    @property
    def reference_id(self):
        """Gets the reference_id of this ResponseCmdkSearchResultInfo.  # noqa: E501


        :return: The reference_id of this ResponseCmdkSearchResultInfo.  # noqa: E501
        :rtype: int
        """
        return self._reference_id

    @reference_id.setter
    def reference_id(self, reference_id):
        """Sets the reference_id of this ResponseCmdkSearchResultInfo.


        :param reference_id: The reference_id of this ResponseCmdkSearchResultInfo.  # noqa: E501
        :type reference_id: int
        """
        if self.local_vars_configuration.client_side_validation and reference_id is None:  # noqa: E501
            raise ValueError("Invalid value for `reference_id`, must not be `None`")  # noqa: E501

        self._reference_id = reference_id

    @property
    def type(self):
        """Gets the type of this ResponseCmdkSearchResultInfo.  # noqa: E501


        :return: The type of this ResponseCmdkSearchResultInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ResponseCmdkSearchResultInfo.


        :param type: The type of this ResponseCmdkSearchResultInfo.  # noqa: E501
        :type type: str
        """

        self._type = type

    @property
    def updated_dt(self):
        """Gets the updated_dt of this ResponseCmdkSearchResultInfo.  # noqa: E501


        :return: The updated_dt of this ResponseCmdkSearchResultInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this ResponseCmdkSearchResultInfo.


        :param updated_dt: The updated_dt of this ResponseCmdkSearchResultInfo.  # noqa: E501
        :type updated_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_dt`, must not be `None`")  # noqa: E501

        self._updated_dt = updated_dt

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseCmdkSearchResultInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseCmdkSearchResultInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class EtreeElement(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'attr': 'list[EtreeAttr]',
        'child': 'list[object]',
        'space': 'str',
        'tag': 'str'
    }

    attribute_map = {
        'attr': 'Attr',
        'child': 'Child',
        'space': 'Space',
        'tag': 'Tag'
    }

    def __init__(self, attr=None, child=None, space=None, tag=None, local_vars_configuration=None):  # noqa: E501
        """EtreeElement - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._attr = None
        self._child = None
        self._space = None
        self._tag = None
        self.discriminator = None

        if attr is not None:
            self.attr = attr
        if child is not None:
            self.child = child
        if space is not None:
            self.space = space
        if tag is not None:
            self.tag = tag

    @property
    def attr(self):
        """Gets the attr of this EtreeElement.  # noqa: E501


        :return: The attr of this EtreeElement.  # noqa: E501
        :rtype: list[EtreeAttr]
        """
        return self._attr

    @attr.setter
    def attr(self, attr):
        """Sets the attr of this EtreeElement.


        :param attr: The attr of this EtreeElement.  # noqa: E501
        :type attr: list[EtreeAttr]
        """

        self._attr = attr

    @property
    def child(self):
        """Gets the child of this EtreeElement.  # noqa: E501


        :return: The child of this EtreeElement.  # noqa: E501
        :rtype: list[object]
        """
        return self._child

    @child.setter
    def child(self, child):
        """Sets the child of this EtreeElement.


        :param child: The child of this EtreeElement.  # noqa: E501
        :type child: list[object]
        """

        self._child = child

    @property
    def space(self):
        """Gets the space of this EtreeElement.  # noqa: E501


        :return: The space of this EtreeElement.  # noqa: E501
        :rtype: str
        """
        return self._space

    @space.setter
    def space(self, space):
        """Sets the space of this EtreeElement.


        :param space: The space of this EtreeElement.  # noqa: E501
        :type space: str
        """

        self._space = space

    @property
    def tag(self):
        """Gets the tag of this EtreeElement.  # noqa: E501


        :return: The tag of this EtreeElement.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this EtreeElement.


        :param tag: The tag of this EtreeElement.  # noqa: E501
        :type tag: str
        """

        self._tag = tag

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EtreeElement):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EtreeElement):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ProtoLLMVectorDBConnConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'authentication': 'ProtoLLMVectorDBConnAuth',
        'created_by': 'ProtoUser',
        'created_dt': 'float',
        'id': 'int',
        'name': 'str',
        'updated_dt': 'float',
        'url': 'str',
        'vdb_type': 'str'
    }

    attribute_map = {
        'authentication': 'authentication',
        'created_by': 'created_by',
        'created_dt': 'created_dt',
        'id': 'id',
        'name': 'name',
        'updated_dt': 'updated_dt',
        'url': 'url',
        'vdb_type': 'vdb_type'
    }

    def __init__(self, authentication=None, created_by=None, created_dt=None, id=None, name=None, updated_dt=None, url=None, vdb_type=None, local_vars_configuration=None):  # noqa: E501
        """ProtoLLMVectorDBConnConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._authentication = None
        self._created_by = None
        self._created_dt = None
        self._id = None
        self._name = None
        self._updated_dt = None
        self._url = None
        self._vdb_type = None
        self.discriminator = None

        self.authentication = authentication
        if created_by is not None:
            self.created_by = created_by
        if created_dt is not None:
            self.created_dt = created_dt
        if id is not None:
            self.id = id
        self.name = name
        if updated_dt is not None:
            self.updated_dt = updated_dt
        self.url = url
        self.vdb_type = vdb_type

    @property
    def authentication(self):
        """Gets the authentication of this ProtoLLMVectorDBConnConfig.  # noqa: E501


        :return: The authentication of this ProtoLLMVectorDBConnConfig.  # noqa: E501
        :rtype: ProtoLLMVectorDBConnAuth
        """
        return self._authentication

    @authentication.setter
    def authentication(self, authentication):
        """Sets the authentication of this ProtoLLMVectorDBConnConfig.


        :param authentication: The authentication of this ProtoLLMVectorDBConnConfig.  # noqa: E501
        :type authentication: ProtoLLMVectorDBConnAuth
        """
        if self.local_vars_configuration.client_side_validation and authentication is None:  # noqa: E501
            raise ValueError("Invalid value for `authentication`, must not be `None`")  # noqa: E501

        self._authentication = authentication

    @property
    def created_by(self):
        """Gets the created_by of this ProtoLLMVectorDBConnConfig.  # noqa: E501


        :return: The created_by of this ProtoLLMVectorDBConnConfig.  # noqa: E501
        :rtype: ProtoUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ProtoLLMVectorDBConnConfig.


        :param created_by: The created_by of this ProtoLLMVectorDBConnConfig.  # noqa: E501
        :type created_by: ProtoUser
        """

        self._created_by = created_by

    @property
    def created_dt(self):
        """Gets the created_dt of this ProtoLLMVectorDBConnConfig.  # noqa: E501


        :return: The created_dt of this ProtoLLMVectorDBConnConfig.  # noqa: E501
        :rtype: float
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this ProtoLLMVectorDBConnConfig.


        :param created_dt: The created_dt of this ProtoLLMVectorDBConnConfig.  # noqa: E501
        :type created_dt: float
        """

        self._created_dt = created_dt

    @property
    def id(self):
        """Gets the id of this ProtoLLMVectorDBConnConfig.  # noqa: E501


        :return: The id of this ProtoLLMVectorDBConnConfig.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProtoLLMVectorDBConnConfig.


        :param id: The id of this ProtoLLMVectorDBConnConfig.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ProtoLLMVectorDBConnConfig.  # noqa: E501


        :return: The name of this ProtoLLMVectorDBConnConfig.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProtoLLMVectorDBConnConfig.


        :param name: The name of this ProtoLLMVectorDBConnConfig.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def updated_dt(self):
        """Gets the updated_dt of this ProtoLLMVectorDBConnConfig.  # noqa: E501


        :return: The updated_dt of this ProtoLLMVectorDBConnConfig.  # noqa: E501
        :rtype: float
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this ProtoLLMVectorDBConnConfig.


        :param updated_dt: The updated_dt of this ProtoLLMVectorDBConnConfig.  # noqa: E501
        :type updated_dt: float
        """

        self._updated_dt = updated_dt

    @property
    def url(self):
        """Gets the url of this ProtoLLMVectorDBConnConfig.  # noqa: E501


        :return: The url of this ProtoLLMVectorDBConnConfig.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this ProtoLLMVectorDBConnConfig.


        :param url: The url of this ProtoLLMVectorDBConnConfig.  # noqa: E501
        :type url: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def vdb_type(self):
        """Gets the vdb_type of this ProtoLLMVectorDBConnConfig.  # noqa: E501


        :return: The vdb_type of this ProtoLLMVectorDBConnConfig.  # noqa: E501
        :rtype: str
        """
        return self._vdb_type

    @vdb_type.setter
    def vdb_type(self, vdb_type):
        """Sets the vdb_type of this ProtoLLMVectorDBConnConfig.


        :param vdb_type: The vdb_type of this ProtoLLMVectorDBConnConfig.  # noqa: E501
        :type vdb_type: str
        """
        if self.local_vars_configuration.client_side_validation and vdb_type is None:  # noqa: E501
            raise ValueError("Invalid value for `vdb_type`, must not be `None`")  # noqa: E501
        allowed_values = ["chroma"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and vdb_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `vdb_type` ({0}), must be one of {1}"  # noqa: E501
                .format(vdb_type, allowed_values)
            )

        self._vdb_type = vdb_type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProtoLLMVectorDBConnConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProtoLLMVectorDBConnConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class LLMWorkflowCreateAPIInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'description': 'str',
        'duplicated_workflow_id': 'int',
        'kernel_cluster_id': 'int',
        'kernel_resource_preset_id': 'int',
        'name': 'str',
        'permission_config': 'V1LLMPermissionConfig',
        'workflow_template_id': 'int'
    }

    attribute_map = {
        'description': 'description',
        'duplicated_workflow_id': 'duplicated_workflow_id',
        'kernel_cluster_id': 'kernel_cluster_id',
        'kernel_resource_preset_id': 'kernel_resource_preset_id',
        'name': 'name',
        'permission_config': 'permission_config',
        'workflow_template_id': 'workflow_template_id'
    }

    def __init__(self, description=None, duplicated_workflow_id=None, kernel_cluster_id=None, kernel_resource_preset_id=None, name=None, permission_config=None, workflow_template_id=None, local_vars_configuration=None):  # noqa: E501
        """LLMWorkflowCreateAPIInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._description = None
        self._duplicated_workflow_id = None
        self._kernel_cluster_id = None
        self._kernel_resource_preset_id = None
        self._name = None
        self._permission_config = None
        self._workflow_template_id = None
        self.discriminator = None

        if description is not None:
            self.description = description
        self.duplicated_workflow_id = duplicated_workflow_id
        self.kernel_cluster_id = kernel_cluster_id
        self.kernel_resource_preset_id = kernel_resource_preset_id
        self.name = name
        if permission_config is not None:
            self.permission_config = permission_config
        self.workflow_template_id = workflow_template_id

    @property
    def description(self):
        """Gets the description of this LLMWorkflowCreateAPIInput.  # noqa: E501


        :return: The description of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this LLMWorkflowCreateAPIInput.


        :param description: The description of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def duplicated_workflow_id(self):
        """Gets the duplicated_workflow_id of this LLMWorkflowCreateAPIInput.  # noqa: E501


        :return: The duplicated_workflow_id of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._duplicated_workflow_id

    @duplicated_workflow_id.setter
    def duplicated_workflow_id(self, duplicated_workflow_id):
        """Sets the duplicated_workflow_id of this LLMWorkflowCreateAPIInput.


        :param duplicated_workflow_id: The duplicated_workflow_id of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :type duplicated_workflow_id: int
        """

        self._duplicated_workflow_id = duplicated_workflow_id

    @property
    def kernel_cluster_id(self):
        """Gets the kernel_cluster_id of this LLMWorkflowCreateAPIInput.  # noqa: E501


        :return: The kernel_cluster_id of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._kernel_cluster_id

    @kernel_cluster_id.setter
    def kernel_cluster_id(self, kernel_cluster_id):
        """Sets the kernel_cluster_id of this LLMWorkflowCreateAPIInput.


        :param kernel_cluster_id: The kernel_cluster_id of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :type kernel_cluster_id: int
        """
        if self.local_vars_configuration.client_side_validation and kernel_cluster_id is None:  # noqa: E501
            raise ValueError("Invalid value for `kernel_cluster_id`, must not be `None`")  # noqa: E501

        self._kernel_cluster_id = kernel_cluster_id

    @property
    def kernel_resource_preset_id(self):
        """Gets the kernel_resource_preset_id of this LLMWorkflowCreateAPIInput.  # noqa: E501


        :return: The kernel_resource_preset_id of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._kernel_resource_preset_id

    @kernel_resource_preset_id.setter
    def kernel_resource_preset_id(self, kernel_resource_preset_id):
        """Sets the kernel_resource_preset_id of this LLMWorkflowCreateAPIInput.


        :param kernel_resource_preset_id: The kernel_resource_preset_id of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :type kernel_resource_preset_id: int
        """
        if self.local_vars_configuration.client_side_validation and kernel_resource_preset_id is None:  # noqa: E501
            raise ValueError("Invalid value for `kernel_resource_preset_id`, must not be `None`")  # noqa: E501

        self._kernel_resource_preset_id = kernel_resource_preset_id

    @property
    def name(self):
        """Gets the name of this LLMWorkflowCreateAPIInput.  # noqa: E501


        :return: The name of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LLMWorkflowCreateAPIInput.


        :param name: The name of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def permission_config(self):
        """Gets the permission_config of this LLMWorkflowCreateAPIInput.  # noqa: E501


        :return: The permission_config of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :rtype: V1LLMPermissionConfig
        """
        return self._permission_config

    @permission_config.setter
    def permission_config(self, permission_config):
        """Sets the permission_config of this LLMWorkflowCreateAPIInput.


        :param permission_config: The permission_config of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :type permission_config: V1LLMPermissionConfig
        """

        self._permission_config = permission_config

    @property
    def workflow_template_id(self):
        """Gets the workflow_template_id of this LLMWorkflowCreateAPIInput.  # noqa: E501


        :return: The workflow_template_id of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._workflow_template_id

    @workflow_template_id.setter
    def workflow_template_id(self, workflow_template_id):
        """Sets the workflow_template_id of this LLMWorkflowCreateAPIInput.


        :param workflow_template_id: The workflow_template_id of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :type workflow_template_id: int
        """

        self._workflow_template_id = workflow_template_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LLMWorkflowCreateAPIInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LLMWorkflowCreateAPIInput):
            return True

        return self.to_dict() != other.to_dict()
